#Anova and Robust group comparisons

cocomo<-read.table("Datasets/COCOMOfull.txt", header=T)
library(car)
library(WRS)

#Robust oneway analysis
kruskal.test(Productivity~Modecat,cocomo)


#Standard ANOVA
names(cocomo)
attach(cocomo)
boxplot(Productivity~Modecat)
table(Modecat)
aggregate(Productivity,by=list(Modecat),FUN=mean)
aggregate(Productivity,by=list(Modecat),FUN=median)
fit<-aov(Productivity~Modecat)
summary(fit)
qqPlot(fit)
fit2<-aov(log(Productivity)~Modecat)
qqPlot(fit2)



detach(cocomo)
redcoc=subset(cocomo,Select==1)
attach(redcoc)

fitaov=aov(log(Productivity)~Modecat*rvolcat)
summary(fitaov)

qqPlot(fitaov)
influencePlot(fitaov)
interaction.plot(Modecat,rvolcat,log(Productivity),type="b",pch=c(2,4,16,18))
detach(redcoc)

attach(cocomo)
fit~aov(log(Productivity)~Modecat+rvolcat)
summary(fit)
qqPlot(fit)
fit1=aov(log(Productivity)~rvolcat+Modecat)
summary(fit1)

#linear contrasts for tool category using trimmed means

w=list()
w[[1]]=log(Productivity)[TOOLcat=="l"|TOOLcat=="vl"]
w[[2]]=log(Productivity)[TOOLcat=="n"]
w[[3]]=log(Productivity)[TOOLcat=="h"|TOOLcat=="vh"|TOOLcat=="xh"]
vec=c(1,-2,1)


lincon(w,con=vec,tr=.2,alpha=0.05)
m1=mean(w[[1]])
m2=mean(w[[2]])
m3=mean(w[[3]])
lc=m1+m3-2*m2

#Robust

#Robust method based on trimmed means

w=list()
w[[1]]=Productivity[Modecat=="E"]
w[[2]]=Productivity[Modecat=="SD"]
w[[3]]=Productivity[Modecat=="O"]
#trimmed means
t1way(w,tr=0.2)

#effect size
esmcp(w,tr=0.2)

aggregate(Productivity,by=list(Modecat),FUN=mean)
#cliff's method
cidmulv2(w,CI.FWE=T)

#bdm method
bdm(w)

#two-way Brunner - no need for equal projects per cell




w=list()



w[[1]]=Productivity[Modecat=="E"&(rvolcat=="n"|rvolcat=="l")]
w[[2]]=Productivity[Modecat=="SD"&(rvolcat=="n"|rvolcat=="l")]
w[[3]]=Productivity[Modecat=="O"&(rvolcat=="n"|rvolcat=="l")]
w[[4]]=Productivity[Modecat=="E"&(rvolcat=="h"|rvolcat=="vh")]
w[[5]]=Productivity[Modecat=="SD"&(rvolcat=="h"|rvolcat=="vh")]
w[[6]]=Productivity[Modecat=="O"&(rvolcat=="h"|rvolcat=="vh")]


par(mfrow=c(2,3))
boxplot(w[[3]],ylim=c(0,1.1))
boxplot(w[[2]],ylim=c(0,1.1))
boxplot(w[[1]],ylim=c(0,1.1))
boxplot(w[[6]],ylim=c(0,1.1))
boxplot(w[[5]],ylim=c(0,1.1))
boxplot(w[[4]],ylim=c(0,1.1))




# Factor A=rvolcar, Factor B=Modecat

t2way(2,3,w,tr=.1)
bdm2way(2,3,w)

v=list()
v[[1]]=log(Productivity)[Modecat=="E"&(rvolcat=="n"|rvolcat=="l")]
v[[2]]=log(Productivity)[Modecat=="E"&(rvolcat=="h"|rvolcat=="vh")]
v[[3]]=log(Productivity)[Modecat=="SD"&(rvolcat=="n"|rvolcat=="l")]
v[[4]]=log(Productivity)[Modecat=="SD"&(rvolcat=="h"|rvolcat=="vh")]
v[[5]]=log(Productivity)[Modecat=="O"&(rvolcat=="n"|rvolcat=="l")]
v[[6]]=log(Productivity)[Modecat=="O"&(rvolcat=="h"|rvolcat=="vh")]

par(mfrow=c(2,3))
boxplot(v[[1]],ylim=c(-5,1))
boxplot(v[[3]],ylim=c(-5,1))
boxplot(v[[5]],ylim=c(-5,1))
boxplot(v[[2]],ylim=c(-5,1))
boxplot(v[[4]],ylim=c(-5,1))
boxplot(v[[6]],ylim=c(-5,1))



t2way(3,2,v,tr=.1)
bdm2way(3,2,v)

#MANOVA

library(MASS)
y<-cbind(log(Effort),log(Dur),log(AKDSI))
aggregate(y,by=list(Modecat),FUN=mean)

fit<-manova(y~Modecat)
summary(fit)
summary.aov(fit)

#Investigate Multivariate normality


centre<-colMeans(y)
n<-nrow(y)
p<-ncol(y)
cov<-cov(y)
d<-mahalanobis(y,centre,cov)
coord<-qqplot(qchisq(ppoints(n),df=p),d,main="Assessing Multivariate Normality", ylab="Mahalanobis D2")
abline(a=0,b=1)
identify(coord$x,coord$y,label=row.names(cocomo))



