library(WRS)

library(car)

iclbt<-read.table("Datasets/iclbt.txt",header=T)


attach(iclbt)

plot(loc[co==1],effort[co==1],ylab="LoC",xlab="Effort",main="Data from ICL")

cor.test(loc[co==1],effort[co==1])


cor.test(loc[co==1 & !(project==7)],effort[co==1&!(project==7)])
cor.test(loc[co==1 & !(project==6)],effort[co==1&!(project==6)])

relplot(loc[co==1],effort[co==1])


cor.test(loc[co==1],effort[co==1],method="spearman")
cor.test(loc[co==1 & !(project==7)],effort[co==1&!(project==7)],method="spearman")
cor.test(loc[co==1 & !(project==6)],effort[co==1&!(project==6)],method="spearman")


cor.test(loc[co==1],effort[co==1],method="kendall")
cor.test(loc[co==1 & !(project==7)],effort[co==1&!(project==7)],method="kendall")
cor.test(loc[co==1 & !(project==6)],effort[co==1&!(project==6)],method="kendall")

x=loc[co==1]
y=effort[co==1]


relplot(x,y)
outmgv(x,y,plotit=T)
wincor(x,y)
corb(x,y,corfun=pbcor,nboot=599)


relplot(loc,effort)

outmgv(loc,effort,plotit=T)
fit=lm(effort~loc,data=iclbt)

plot(effort,loc)
abline(a=17.22,b=.0053322)

x=loc
y=effort
#Theil=-Sen
regplot(x,y,regfun=tsreg,xlab="Loc",ylab="Effort")

x2=log(loc)
y2=log(effort)
fit2=lm(log(effort)~log(loc))

plot(x2,y2,xlab="Log(Loc)",ylab="Log(Effort)")
abline(b=.816,a=-4.1686)

iclbt$co<-factor(c("1","2","3"))
fit=lm(log(effort)~log(loc)+log(dur)+co)

summary(fit)


qqPlot(fit)

residplot<-function(fit,nbreaks=20){
	z<-rstudent(fit)
	hist(z,breaks=nbreaks,freq=FALSE,
	xlab="Residuals",
	main="Distribution of Errors")
	curve(dnorm(x,mean=mean(z), sd=sd(z)),add=T,lwd=2)
	lines(density(z)$x,density(z)$y,lwd=2,lty=2)
	legend("topright",legend=c("Normal Curve","KernelDensity Curve"),lty=1:2,cex=.7)
}

residplot(fit,20)


residplot2<-function(fit,nbreaks=20){
	z<-resid(fit)
	hist(z,breaks=nbreaks,freq=FALSE,
	xlab="Residuals",
	main="Distribution of Errors")
	curve(dnorm(x,mean=mean(z), sd=sd(z)),add=T,lwd=2)
	lines(density(z)$x,density(z)$y,lwd=2,lty=2)
	legend("topright",legend=c("Normal Curve","KernelDensity Curve"),lty=1:2,cex=.7)
}

residplot2(fit,20)

crPlots(fit)

ncvTest(fit)

spreadLevelPlot(fit)

influencePlot(fit,id.method="identify",sub="Circle size proportional to Cook's distance")

newfit=update(fit,subset=-c(16,7))

summary(newfit)

influencePlot(newfit)

#cross-validation
shrinkage<-function(fit,k=10){
require(bootstrap)
theta.fit<-function(x,y) {lsfit(x,y)}

theta.predict<- function(fit,x)  {cbind(1,x)%*%fit$coef}



x<-fit$model[,2:ncol(fit$model)]
y<-fit$model[,1]

results<-crossval(x,y,theta.fit,theta.predict,ngroup=k)
r2<- cor(y, fit$fitted.values)^2
r2cv<-cor(y,results$cv.fit)^2

#cat(Original R-Square =)

r2

r2cv

r2-r2cv
#cat(k, Fold Cross-Validation R-square =, r2cv, \n)

#cat(Change =, r2-r2cv, \n)

}
shrinkage(fit,k=5)


#Lowess model

plot(loc,effort)
lines(lowess(loc,effort,f=0.5,iter=3),lwd=2)

lines(lowess(loc,effort,f=0.5,iter=0),lwd=2,lty=2)

plot(dur,effort)
lines(lowess(effort,dur,f=0.5,iter=0),lwd=2)

mod.lo<-loess(formula=effort~loc+dur,data=iclbt,span=0.5,degree=1)

plot(effort, fitted(mod.lo),main="Multiple regression using Lowess", ylab="Fitted values")
abline(a=0,b=1)


y=log(fitted(mod.lo))
plot(log(effort),y,main="Values on log scale",ylab="Log Fitted Values")
abline(a=0,b=1)

kfit=kerreg(loc,effort,xlab="loc",ylab="effort")

tsfit=tsreg(x,effort,iter=10)
tsfit
tsfitted=effort+resid(tsfit)
plot(effort,tsfitted)
abline(a=0,b=1)

